@@ -2,5 +2,6 @@
 use warnings;
 use strict;
 use JSON::Repair ':all';
-my $r = repair_json ('{"stuff":["good');
-print "$r\n";
+print repair_json (
+    '{"stuff":["good'
+);
